@@ -2,6 +2,7 @@
 import datetime as dti
 import os
 import pathlib
+from typing import no_type_check
 
 import yaml
 
@@ -52,6 +53,7 @@ ACROSS = {
 }
 
 
+@no_type_check
 def process_meta(aspects: str) -> gat.Meta | int:
     """TODO."""
     meta_path = DOC_BASE / aspects[gat.KEY_META]
@@ -71,7 +73,8 @@ def process_meta(aspects: str) -> gat.Meta | int:
         if not base_meta_path.is_file() or not base_meta_path.stat().st_size:
             log.error(
                 f'metadata declares import of base data from ({base_meta_path.name})'
-                f' but failed to find non-empty base file at {base_meta_path}')
+                f' but failed to find non-empty base file at {base_meta_path}'
+            )
             return 1
         with open(base_meta_path, 'rt', encoding=ENCODING) as handle:
             base_data = yaml.safe_load(handle)
@@ -83,7 +86,11 @@ def process_meta(aspects: str) -> gat.Meta | int:
     return metadata
 
 
-def weave_setup_font_path(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_setup_font_path(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the xxxx from mapper or default for driver.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_FONT_%_PATH_%%')
@@ -92,9 +99,7 @@ def weave_setup_font_path(mapper: dict[str, str | int | bool | None], text: str,
     if mapper.get('font_path'):
         font_path = mapper.get('font_path')
         if not pathlib.Path(font_path).is_dir():
-            log.warning(
-                f'font_path ({font_path}) is no directory on this system - rendering may not work as intended'
-            )
+            log.warning(f'font_path ({font_path}) is no directory on this system - rendering may not work as intended')
         ACROSS['eff_font_folder'] = font_path
         return text.replace(VALUE_SLOT, font_path)
     else:
@@ -103,7 +108,11 @@ def weave_setup_font_path(mapper: dict[str, str | int | bool | None], text: str,
         return text.replace(VALUE_SLOT, defaults['font_path'])
 
 
-def weave_setup_font_suffix(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_setup_font_suffix(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the font_suffix from mapper or default for driver.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_FONT_%_SUFFIX_%%')
@@ -112,9 +121,7 @@ def weave_setup_font_suffix(mapper: dict[str, str | int | bool | None], text: st
     if mapper.get('font_suffix'):
         font_suffix = mapper.get('font_suffix')
         if font_suffix not in ('.otf', '.ttf'):
-            log.warning(
-                f'font_suffix ({font_suffix}) is unexpected - rendering may not work as intended'
-            )
+            log.warning(f'font_suffix ({font_suffix}) is unexpected - rendering may not work as intended')
         ACROSS['eff_font_suffix'] = font_suffix
         return text.replace(VALUE_SLOT, font_suffix)
     else:
@@ -123,7 +130,11 @@ def weave_setup_font_suffix(mapper: dict[str, str | int | bool | None], text: st
         return text.replace(VALUE_SLOT, defaults['font_suffix'])
 
 
-def weave_setup_bold_font(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_setup_bold_font(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the bold_font from mapper or default for driver.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_BOLD_%_FONT_%%')
@@ -145,7 +156,11 @@ def weave_setup_bold_font(mapper: dict[str, str | int | bool | None], text: str,
         return text.replace(VALUE_SLOT, defaults['bold_font'])
 
 
-def weave_setup_italic_font(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_setup_italic_font(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the italic_font from mapper or default for driver.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_ITALIC_%_FONT_%%')
@@ -167,7 +182,11 @@ def weave_setup_italic_font(mapper: dict[str, str | int | bool | None], text: st
         return text.replace(VALUE_SLOT, defaults['italic_font'])
 
 
-def weave_setup_bold_italic_font(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_setup_bold_italic_font(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the bold_italic_font from mapper or default for driver.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_BOLDITALIC_%_FONT_%%')
@@ -189,7 +208,11 @@ def weave_setup_bold_italic_font(mapper: dict[str, str | int | bool | None], tex
         return text.replace(VALUE_SLOT, defaults['bold_italic_font'])
 
 
-def weave_setup_main_font(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_setup_main_font(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the main_font from mapper or default for driver.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_MAIN_%_FONT_%%')
@@ -211,7 +234,11 @@ def weave_setup_main_font(mapper: dict[str, str | int | bool | None], text: str,
         return text.replace(VALUE_SLOT, defaults['main_font'])
 
 
-def weave_setup_fixed_font_package(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_setup_fixed_font_package(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the fixed_font_package from mapper or default for driver.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_FIXED_%_FONT_%_PACKAGE_%%')
@@ -230,7 +257,11 @@ def weave_setup_fixed_font_package(mapper: dict[str, str | int | bool | None], t
         return text.replace(VALUE_SLOT, defaults['fixed_font_package'])
 
 
-def weave_setup_code_fontsize(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_setup_code_fontsize(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the code_fontsize from mapper or default for driver.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_CODE_%_FONTSIZE_%%')
@@ -262,18 +293,24 @@ def weave_setup_code_fontsize(mapper: dict[str, str | int | bool | None], text:
             log.info(f'valid values for code_fontsize must be in {bs}{(", " + bs).join(sizes)}')
             log.warning(
                 f'overriding code font size value with the (working) default of ({defaults["code_fontsize"]})'
-                f' - in config that would be {defaults["code_fontsize"]}')
+                f' - in config that would be {defaults["code_fontsize"]}'
+            )
             return text.replace(VALUE_SLOT, defaults['code_fontsize'])
         else:
             return text.replace(VALUE_SLOT, code_fontsize)
     else:
         log.warning(
             f'code_fontsize value missing ... setting default ({defaults["code_fontsize"]})'
-            f' - in config that would be {defaults["code_fontsize"]}')
+            f' - in config that would be {defaults["code_fontsize"]}'
+        )
         return text.replace(VALUE_SLOT, defaults['code_fontsize'])
 
 
-def weave_setup_chosen_logo(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_setup_chosen_logo(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the chosen_logo from mapper or default for driver.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_CHOSEN_%_LOGO_%%')
@@ -293,7 +330,11 @@ def weave_setup_chosen_logo(mapper: dict[str, str | int | bool | None], text: st
         return text.replace(VALUE_SLOT, defaults['chosen_logo'])
 
 
-def dispatch_setup_weaver(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def dispatch_setup_weaver(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Dispatch the driver weaver by mapping to handled groups per source marker."""
     dispatch = {
         '%%_PATCH_%_FONT_%_PATH_%%': weave_setup_font_path,
@@ -312,16 +353,21 @@ def dispatch_setup_weaver(mapper: dict[str, str | int | bool | None], text: str,
     return text
 
 
-def weave_meta_setup(meta_map: gat.Meta, latex: list[str]) -> None:
+@no_type_check
+def weave_meta_setup(meta_map: gat.Meta, latex: list[str]) -> list[str]:
     """TODO."""
     log.info('weaving in the meta data per setup.tex.in into setup.tex ...')
-    completed = [dispatch_setup_weaver(meta_map['document']['common'], line) for line in latex]  # type: ignore
+    completed = [dispatch_setup_weaver(meta_map['document']['common'], line) for line in latex]
     if completed and completed[-1]:
         completed.append('\n')
     return completed
 
 
-def weave_driver_toc_level(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_driver_toc_level(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the toc_level from mapper or default for driver.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_TOC_%_LEVEL_%%')
@@ -337,16 +383,18 @@ def weave_driver_toc_level(mapper: dict[str, str | int | bool | None], text: str
                 )
         except ValueError as err:
             toc_level = 2
-            log.warning(
-                f'toc_level ({mapper["toc_level"]}) not in (1, 2, 3, 4) - resorting to default ({toc_level})'
-            )
+            log.warning(f'toc_level ({mapper["toc_level"]}) not in (1, 2, 3, 4) - resorting to default ({toc_level})')
             log.error(f'error detail: {err}')
     else:
         log.warning(f'toc_level value missing ... setting default ({toc_level})')
     return text.replace(VALUE_SLOT, str(toc_level))
 
 
-def weave_driver_list_of_figures(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_driver_list_of_figures(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the list_of_figures from mapper or default for driver.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_LOF_%%')
@@ -359,7 +407,7 @@ def weave_driver_list_of_figures(mapper: dict[str, str | int | bool | None], tex
             lof = '%'
             log.warning(
                 f"list_of_figures ({mapper['list_of_figures']}) not in ('', '%')"
-                f" - resorting to default ({lof}) i.e. commenting out the list of figures"
+                f' - resorting to default ({lof}) i.e. commenting out the list of figures'
             )
     else:
         log.warning('list_of_figures value missing ... setting default (comment out the lof per %)')
@@ -367,7 +415,11 @@ def weave_driver_list_of_figures(mapper: dict[str, str | int | bool | None], tex
     return text.replace(VALUE_SLOT, '%')
 
 
-def weave_driver_list_of_tables(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_driver_list_of_tables(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the list_of_tables from mapper or default for driver.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_LOT_%%')
@@ -380,7 +432,7 @@ def weave_driver_list_of_tables(mapper: dict[str, str | int | bool | None], text
             lof = '%'
             log.warning(
                 f"list_of_tables ({mapper['list_of_tables']}) not in ('', '%')"
-                f" - resorting to default ({lof}) i.e. commenting out the list of tables"
+                f' - resorting to default ({lof}) i.e. commenting out the list of tables'
             )
     else:
         log.warning('list_of_tables value missing ... setting default (comment out the lot per %)')
@@ -388,7 +440,11 @@ def weave_driver_list_of_tables(mapper: dict[str, str | int | bool | None], text
     return text.replace(VALUE_SLOT, '%')
 
 
-def dispatch_driver_weaver(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def dispatch_driver_weaver(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Dispatch the driver weaver by mapping to handled groups per source marker."""
     dispatch = {
         '%%_PATCH_%_TOC_%_LEVEL_%%': weave_driver_toc_level,
@@ -401,16 +457,21 @@ def dispatch_driver_weaver(mapper: dict[str, str | int | bool | None], text: str
     return text
 
 
-def weave_meta_driver(meta_map: gat.Meta, latex: list[str]) -> None:
+@no_type_check
+def weave_meta_driver(meta_map: gat.Meta, latex: list[str]) -> list[str]:
     """TODO."""
     log.info('weaving in the meta data per driver.tex.in into driver.tex ...')
-    completed = [dispatch_driver_weaver(meta_map['document']['common'], line) for line in latex]  # type: ignore
+    completed = [dispatch_driver_weaver(meta_map['document']['common'], line) for line in latex]
     if completed and completed[-1]:
         completed.append('\n')
     return completed
 
 
-def weave_meta_part_header_title(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_header_title(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the header_title from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_HEADER_%_TITLE_%%')
@@ -422,7 +483,11 @@ def weave_meta_part_header_title(mapper: dict[str, str | int | bool | None], tex
         return text.replace(VALUE_SLOT, mapper['title'])
 
 
-def weave_meta_part_title(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_title(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the title from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_MAIN_%_TITLE_%%')
@@ -430,7 +495,11 @@ def weave_meta_part_title(mapper: dict[str, str | int | bool | None], text: str,
     return text.replace(VALUE_SLOT, mapper['title'])
 
 
-def weave_meta_part_sub_title(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_sub_title(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the sub_title from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_SUB_%_TITLE_%%')
@@ -442,7 +511,11 @@ def weave_meta_part_sub_title(mapper: dict[str, str | int | bool | None], text:
         return text.replace(VALUE_SLOT, ' ')
 
 
-def weave_meta_part_header_type(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_header_type(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the header_type from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_TYPE_%%')
@@ -454,11 +527,42 @@ def weave_meta_part_header_type(mapper: dict[str, str | int | bool | None], text
         return text.replace(VALUE_SLOT, 'Engineering Document')
 
 
-def weave_meta_part_header_id(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_header_id_label(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
+    """Weave in the header_id_label from mapper or default.
+
+    Trigger is text.rstrip().endswith('%%_PATCH_%_ID_%_LABEL_%%')
+    """
+    if mapper.get('header_id_show', None) is not None and not mapper['header_id_show']:
+        log.info('header_id_show set to false - hiding id slot in header by setting label to a single space(" ")')
+        return text.replace(VALUE_SLOT, ' ')
+    log.info('header_id_show not set - considering header_id_label ...')
+    if mapper.get('header_id_label'):
+        pub_id_label = mapper['header_id_label'].strip()
+        if not pub_id_label:
+            pub_id_label = ' '  # single space to please the backend parser
+        return text.replace(VALUE_SLOT, pub_id_label)
+    else:
+        log.warning('header_id_label value missing ... setting default(Doc. ID:)')
+        return text.replace(VALUE_SLOT, 'Doc. ID:')
+
+
+@no_type_check
+def weave_meta_part_header_id(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the header_id from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_ID_%%')
     """
+    if mapper.get('header_id_show', None) is not None and not mapper['header_id_show']:
+        log.info('header_id_show set to false - hiding id slot in header by setting value to a single space(" ")')
+        return text.replace(VALUE_SLOT, ' ')
+    log.info('header_id_show not set - considering header_id ...')
     if mapper.get('header_id'):
         return text.replace(VALUE_SLOT, mapper['header_id'])
     else:
@@ -466,7 +570,11 @@ def weave_meta_part_header_id(mapper: dict[str, str | int | bool | None], text:
         return text.replace(VALUE_SLOT, 'P99999')
 
 
-def weave_meta_part_issue(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_issue(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the issue from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_ISSUE_%%')
@@ -478,7 +586,11 @@ def weave_meta_part_issue(mapper: dict[str, str | int | bool | None], text: str,
         return text.replace(VALUE_SLOT, '01')
 
 
-def weave_meta_part_revision(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_revision(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the revision from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_REVISION_%%')
@@ -490,24 +602,70 @@ def weave_meta_part_revision(mapper: dict[str, str | int | bool | None], text: s
         return text.replace(VALUE_SLOT, '00')
 
 
-def weave_meta_part_header_date(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_header_date_label(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
+    """Weave in the header_date_label from mapper or default.
+
+    Trigger is text.rstrip().endswith('%%_PATCH_%_DATE_%_LABEL_%%')
+    """
+    if mapper.get('header_date_show', None) is not None and not mapper['header_date_show']:
+        log.info('header_date_show set to false - hiding date slot in header by setting label to a single space(" ")')
+        return text.replace(VALUE_SLOT, ' ')
+    log.info('header_date_show not set - considering header_date_label ...')
+    if mapper.get('header_date_label'):
+        pub_date_label = mapper['header_date_label'].strip()
+        if not pub_date_label:
+            pub_date_label = ' '  # single space to please the backend parser
+        return text.replace(VALUE_SLOT, pub_date_label)
+    else:
+        log.warning('header_date_label value missing ... setting default(Date:)')
+        return text.replace(VALUE_SLOT, 'Date:')
+
+
+@no_type_check
+def weave_meta_part_header_date(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the header_date from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_DATE_%%')
     """
-    today = dti.datetime.today()
-    pub_date_today = today.strftime('%d %b %Y').upper()
-    if mapper.get('header_date'):
-        pub_date = mapper['header_date'].strip()
-        if pub_date == MAGIC_OF_TODAY:
-            pub_date = pub_date_today
-        return text.replace(VALUE_SLOT, pub_date)
+    if mapper.get('header_date_show', None) is not None and not mapper['header_date_show']:
+        log.info('header_date_show set to false - hiding date slot in header by setting value to a single space(" ")')
+        return text.replace(VALUE_SLOT, ' ')
+    log.info('header_date_show not set - considering header_date ...')
+    if mapper.get('header_date_enable_auto', None) is not None and not mapper['header_date_enable_auto']:
+        log.info('header_date_enable_auto set to false - setting that slot value as is (no date semantics enforced)')
+        if mapper.get('header_date'):
+            pub_date_or_any = mapper['header_date'].strip()
+            if not pub_date_or_any:
+                pub_date_or_any = ' '  # single space to please the backend parser
+            return text.replace(VALUE_SLOT, pub_date_or_any)
+        else:
+            log.warning('header_date value missing and as-is mode ... setting to single space ( ) a.k.a. hiding')
+            return text.replace(VALUE_SLOT, ' ')
     else:
-        log.warning(f'header_date value missing ... setting default as today({pub_date_today})')
-        return text.replace(VALUE_SLOT, pub_date_today)
+        today = dti.datetime.today()
+        pub_date_today = today.strftime('%d %b %Y').upper()
+        if mapper.get('header_date'):
+            pub_date = mapper['header_date'].strip()
+            if pub_date == MAGIC_OF_TODAY:
+                pub_date = pub_date_today
+            return text.replace(VALUE_SLOT, pub_date)
+        else:
+            log.warning(f'header_date value missing ... setting default as today({pub_date_today})')
+            return text.replace(VALUE_SLOT, pub_date_today)
 
 
-def weave_meta_part_footer_frame_note(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_footer_frame_note(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the footer_frame_note from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_FRAME_%_NOTE_%%')
@@ -519,7 +677,11 @@ def weave_meta_part_footer_frame_note(mapper: dict[str, str | int | bool | None]
         return text.replace(VALUE_SLOT, 'VERY CONSEQUENTIAL')
 
 
-def weave_meta_part_footer_page_number_prefix(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_footer_page_number_prefix(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the footer_page_number_prefix from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_FOOT_%_PAGE_%_COUNTER_%_LABEL_%%')
@@ -531,7 +693,11 @@ def weave_meta_part_footer_page_number_prefix(mapper: dict[str, str | int | bool
         return text.replace(VALUE_SLOT, 'Page')
 
 
-def weave_meta_part_change_log_issue_label(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_change_log_issue_label(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the change_log_issue_label from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_CHANGELOG_%_ISSUE_%_LABEL_%%')
@@ -543,7 +709,11 @@ def weave_meta_part_change_log_issue_label(mapper: dict[str, str | int | bool |
         return text.replace(VALUE_SLOT, 'Iss.')
 
 
-def weave_meta_part_change_log_revision_label(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_change_log_revision_label(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the change_log_revision_label from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_CHANGELOG_%_REVISION_%_LABEL_%%')
@@ -555,7 +725,11 @@ def weave_meta_part_change_log_revision_label(mapper: dict[str, str | int | bool
         return text.replace(VALUE_SLOT, 'Rev.')
 
 
-def weave_meta_part_change_log_date_label(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_change_log_date_label(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the change_log_date_label from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_CHANGELOG_%_DATE_%_LABEL_%%')
@@ -567,7 +741,11 @@ def weave_meta_part_change_log_date_label(mapper: dict[str, str | int | bool | N
         return text.replace(VALUE_SLOT, 'Date')
 
 
-def weave_meta_part_change_log_author_label(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_change_log_author_label(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the change_log_author_label from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_CHANGELOG_%_AUTHOR_%_LABEL_%%')
@@ -579,7 +757,11 @@ def weave_meta_part_change_log_author_label(mapper: dict[str, str | int | bool |
         return text.replace(VALUE_SLOT, 'Author')
 
 
-def weave_meta_part_change_log_description_label(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_change_log_description_label(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the change_log_description_label from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_CHANGELOG_%_DESCRIPTION_%_LABEL_%%')
@@ -591,7 +773,11 @@ def weave_meta_part_change_log_description_label(mapper: dict[str, str | int | b
         return text.replace(VALUE_SLOT, 'Description')
 
 
-def weave_meta_part_approvals_role_label(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_approvals_role_label(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the approvals_role_label from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_APPROVALS_%_ROLE_%_LABEL_%%')
@@ -603,7 +789,11 @@ def weave_meta_part_approvals_role_label(mapper: dict[str, str | int | bool | No
         return text.replace(VALUE_SLOT, 'Approvals')
 
 
-def weave_meta_part_approvals_name_label(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_approvals_name_label(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the approvals_name_label from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_APPROVALS_%_NAME_%_LABEL_%%')
@@ -615,7 +805,11 @@ def weave_meta_part_approvals_name_label(mapper: dict[str, str | int | bool | No
         return text.replace(VALUE_SLOT, 'Name')
 
 
-def weave_meta_part_approvals_date_and_signature_label(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_approvals_date_and_signature_label(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the approvals_date_and_signature_label from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_APPROVALS_%_DATE_%_AND_%_SIGNATURE_%_LABEL_%%')
@@ -627,11 +821,44 @@ def weave_meta_part_approvals_date_and_signature_label(mapper: dict[str, str | i
         return text.replace(VALUE_SLOT, 'Date and Signature')
 
 
-def weave_meta_part_header_issue_revision_combined(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_header_issue_revision_combined_label(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
+    """Weave in the header_issue_revision_combined_label from mapper or default.
+
+    Trigger is text.rstrip().endswith('%%_PATCH_%_ISSUE_%_REVISION_%_COMBINED_%_LABEL_%%')
+    """
+    do_show_key = 'header_issue_revision_combined_show'
+    if mapper.get(do_show_key, None) is not None and not mapper[do_show_key]:
+        log.info(f'{do_show_key} set to false' ' - hiding date slot in header by setting label to a single space(" ")')
+        return text.replace(VALUE_SLOT, ' ')
+    log.info(f'{do_show_key} not set - considering header_issue_revision_combined_label ...')
+    if mapper.get('header_issue_revision_combined_label'):
+        head_iss_rev_comb_label = mapper['header_issue_revision_combined_label'].strip()
+        if not head_iss_rev_comb_label:
+            head_iss_rev_comb_label = ' '  # single space to please the backend parser
+        return text.replace(VALUE_SLOT, head_iss_rev_comb_label)
+    else:
+        log.warning('header_issue_revision_combined_label value missing ... setting default(Issue, Revision:)')
+        return text.replace(VALUE_SLOT, 'Issue, Revision:')
+
+
+@no_type_check
+def weave_meta_part_header_issue_revision_combined(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the header_issue_revision_combined from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_ISSUE_%_REVISION_%_COMBINED_%%')
     """
+    do_show_key = 'header_issue_revision_combined_show'
+    if mapper.get(do_show_key, None) is not None and not mapper[do_show_key]:
+        log.info(f'{do_show_key} set to false' ' - hiding date slot in header by setting value to a single space(" ")')
+        return text.replace(VALUE_SLOT, ' ')
+    log.info(f'{do_show_key} not set - considering header_issue_revision_combined ...')
     if mapper.get('header_issue_revision_combined'):
         return text.replace(VALUE_SLOT, mapper['header_issue_revision_combined'])
     else:
@@ -642,7 +869,11 @@ def weave_meta_part_header_issue_revision_combined(mapper: dict[str, str | int |
         return text.replace(VALUE_SLOT, r'Iss \theMetaIssCode, Rev \theMetaRevCode')
 
 
-def weave_meta_part_proprietary_information(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def weave_meta_part_proprietary_information(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Weave in the proprietary_information from mapper or default.
 
     Trigger is text.rstrip().endswith('%%_PATCH_%_PROPRIETARY_%_INFORMATION_%_LABEL_%%')
@@ -654,30 +885,32 @@ def weave_meta_part_proprietary_information(mapper: dict[str, str | int | bool |
                 prop_info_from_file = pathlib.Path(prop_info).open().read()
                 prop_info = prop_info_from_file
             except (OSError, UnicodeDecodeError) as err:
-                log.error(
-                    f'interpretation of proprietary_information value ({prop_info}) failed with error: {err}'
-                )
+                log.error(f'interpretation of proprietary_information value ({prop_info}) failed with error: {err}')
                 log.warning(f'using value ({prop_info}) directly for proprietary_information')
         else:
             log.info(f'using value ({prop_info}) directly for proprietary_information (no file)')
         return text.replace(VALUE_SLOT, prop_info)
     else:
-        log.warning(
-            'proprietary_information value missing ... setting default (Proprietary Information MISSING)'
-        )
+        log.warning('proprietary_information value missing ... setting default (Proprietary Information MISSING)')
         return text.replace(VALUE_SLOT, 'Proprietary Information MISSING')
 
 
-def dispatch_meta_weaver(mapper: dict[str, str | int | bool | None], text: str, ) -> str:
+@no_type_check
+def dispatch_meta_weaver(
+    mapper: dict[str, str | int | bool | None],
+    text: str,
+) -> str:
     """Dispatch the meta weaver by mapping to handled groups per source marker."""
     dispatch = {
         '%%_PATCH_%_HEADER_%_TITLE_%%': weave_meta_part_header_title,
         '%%_PATCH_%_MAIN_%_TITLE_%%': weave_meta_part_title,
         '%%_PATCH_%_SUB_%_TITLE_%%': weave_meta_part_sub_title,
         '%%_PATCH_%_TYPE_%%': weave_meta_part_header_type,
+        '%%_PATCH_%_ID_%_LABEL_%%': weave_meta_part_header_id_label,
         '%%_PATCH_%_ID_%%': weave_meta_part_header_id,
         '%%_PATCH_%_ISSUE_%%': weave_meta_part_issue,
         '%%_PATCH_%_REVISION_%%': weave_meta_part_revision,
+        '%%_PATCH_%_DATE_%_LABEL_%%': weave_meta_part_header_date_label,
         '%%_PATCH_%_DATE_%%': weave_meta_part_header_date,
         '%%_PATCH_%_FRAME_%_NOTE_%%': weave_meta_part_footer_frame_note,
         '%%_PATCH_%_FOOT_%_PAGE_%_COUNTER_%_LABEL_%%': weave_meta_part_footer_page_number_prefix,
@@ -689,6 +922,7 @@ def dispatch_meta_weaver(mapper: dict[str, str | int | bool | None], text: str,
         '%%_PATCH_%_APPROVALS_%_ROLE_%_LABEL_%%': weave_meta_part_approvals_role_label,
         '%%_PATCH_%_APPROVALS_%_NAME_%_LABEL_%%': weave_meta_part_approvals_name_label,
         '%%_PATCH_%_APPROVALS_%_DATE_%_AND_%_SIGNATURE_%_LABEL_%%': weave_meta_part_approvals_date_and_signature_label,
+        '%%_PATCH_%_ISSUE_%_REVISION_%_COMBINED_%_LABEL_%%': weave_meta_part_header_issue_revision_combined_label,
         '%%_PATCH_%_ISSUE_%_REVISION_%_COMBINED_%%': weave_meta_part_header_issue_revision_combined,
         '%%_PATCH_%_PROPRIETARY_%_INFORMATION_%_LABEL_%%': weave_meta_part_proprietary_information,
     }
@@ -698,14 +932,17 @@ def dispatch_meta_weaver(mapper: dict[str, str | int | bool | None], text: str,
     return text
 
 
-def weave_meta_meta(meta_map: gat.Meta, latex: list[str]) -> None:
+@no_type_check
+def weave_meta_meta(meta_map: gat.Meta, latex: list[str]) -> list[str]:
     """TODO."""
     log.info('weaving in the meta data per metadata.tex.in into metadata.tex ...')
-    completed = [dispatch_meta_weaver(meta_map['document']['common'], line) for line in latex]  # type: ignore
+    completed = [dispatch_meta_weaver(meta_map['document']['common'], line) for line in latex]
     if completed and completed[-1]:
         completed.append('\n')
     return completed
 
+
+@no_type_check
 def weave(
     doc_root: str | pathlib.Path, structure_name: str, target_key: str, facet_key: str, options: dict[str, bool]
 ) -> int:
@@ -722,7 +959,7 @@ def weave(
         doc_root=doc_root, structure_name=structure_name, target_key=target_key, facet_key=facet_key, command='meta'
     )
     log.info(f'prelude teleported processor into the document root at ({os.getcwd()}/)')
-    rel_concat_folder_path = pathlib.Path("render/pdf/")
+    rel_concat_folder_path = pathlib.Path('render/pdf/')
     rel_concat_folder_path.mkdir(parents=True, exist_ok=True)
     os.chdir(rel_concat_folder_path)
     log.info(f'meta (this processor) teleported into the render/pdf location ({os.getcwd()}/)')
